pub struct Poly { /* private fields */ }Expand description
A univariate polynomial in the prime field.
Implementations
Sourceimpl Poly
impl Poly
Sourcepub fn random<R: Rng>(degree: usize, rng: &mut R) -> Self
pub fn random<R: Rng>(degree: usize, rng: &mut R) -> Self
Creates a random polynomial.
Panics
Panics if the degree is too large for the coefficients to fit into a Vec.
Sourcepub fn try_random<R: Rng>(degree: usize, rng: &mut R) -> Result<Self>
pub fn try_random<R: Rng>(degree: usize, rng: &mut R) -> Result<Self>
Creates a random polynomial. This constructor is identical to the Poly::random()
constructor in every way except that this constructor will return an Err where
try_random would return an error.
Sourcepub fn interpolate<T, U, I>(samples_repr: I) -> Self
pub fn interpolate<T, U, I>(samples_repr: I) -> Self
Returns the unique polynomial f of degree samples.len() - 1 with the given values
(x, f(x)).
Sourcepub fn commitment(&self) -> Commitment
pub fn commitment(&self) -> Commitment
Returns the corresponding commitment.